@@ -17,27 +17,7 @@ class Obsplot:
     with ObsplotJsdom depending on the renderer.
     """
 
-    @staticmethod
-    def get_spec(*args, **kwargs) -> dict:
-        """
-        Extract plot specification from args and kwargs, taking into account
-        the alternative specification syntaxes.
-        """
-
-        # Only one dict arg -> spec passed as dict
-        if len(args) == 1 and len(kwargs) == 0 and isinstance(args[0], dict):
-            spec = args[0]
-        # Only one kwarg called spec
-        elif len(args) == 0 and len(kwargs) == 1 and "spec" in kwargs:
-            spec = kwargs["spec"]
-        # Only kwargs -> spec is kwargs
-        elif len(args) == 0 and len(kwargs) > 0:
-            spec = kwargs
-        else:
-            raise ValueError("Incorrect ObsPlot arguments")
-        return spec
-
-    def __new__(cls, renderer: str = "widget", *args, **kwargs) -> Any:
+    def __new__(cls, renderer: str = "widget", debug: bool = False) -> Any:
         """
         Main Obsplot class constructor. Returns a Creator instance depending on the
         renderer passed as argument.
@@ -47,9 +27,11 @@ class Obsplot:
 
         # Plot spec with the configured renderer
         if renderer == "widget":
-            return ObsplotWidgetCreator(*args, **kwargs)
+            return ObsplotWidgetCreator(debug)
         elif renderer == "jsdom":
-            return ObsplotJsdomCreator(*args, **kwargs)
+            if debug:
+                raise ValueError("debug mode is not available with jsdom renderer")
+            return ObsplotJsdomCreator()
         else:
             raise ValueError(
                 f"""
@@ -59,33 +41,68 @@ class Obsplot:
             )
 
 
-class ObsplotWidgetCreator:
+class ObsplotCreator:
+    """
+    Creator class.
+    """
+
+    def get_spec(self, *args, **kwargs):
+        """
+        Extract plot specification from args and kwargs, taking into account
+        the alternative specification syntaxes.
+        """
+
+        # Only one arg which is already a widget output -> returns it as is
+        if len(args) == 1 and len(kwargs) == 0 and isinstance(args[0], (ObsplotWidget)):
+            spec = "widget"
+        # Only one dict arg -> spec passed as dict
+        elif len(args) == 1 and len(kwargs) == 0 and isinstance(args[0], dict):
+            spec = args[0]
+        # Only one kwarg called spec
+        elif len(args) == 0 and len(kwargs) == 1 and "spec" in kwargs:
+            spec = kwargs["spec"]
+        # Only kwargs -> spec is kwargs
+        elif len(args) == 0 and len(kwargs) > 0:
+            spec = kwargs
+        # No arguments given
+        elif len(args) == 0 and len(kwargs) == 0:
+            raise ValueError("Missing plot specification")
+        else:
+            raise ValueError("Incorrect plot specification")
+        return spec
+
+
+class ObsplotWidgetCreator(ObsplotCreator):
     """
     Widget renderer Creator class.
     """
 
-    def __init__(self, *args, **kwargs) -> None:
-        pass
+    def __init__(self, debug: bool = False) -> None:
+        self._debug = debug
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args, **kwargs) -> ObsplotWidget:
         """
         Method called whent an instance is called.
         """
-        spec = Obsplot.get_spec(*args, **kwargs)
-        return ObsplotWidget(spec)
+        spec = self.get_spec(*args, **kwargs)
+        if spec == "widget":
+            return args[0]
+        return ObsplotWidget(spec, debug=self._debug)
 
 
-class ObsplotJsdomCreator:
+class ObsplotJsdomCreator(ObsplotCreator):
     """
     Jsdom renderer Creator class.
     """
 
-    def __init___(self, *args, **kwargs) -> None:
+    def __init__(self) -> None:
         pass
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args, **kwargs) -> None:
         """
         Method called whent an instance is called.
         """
-        spec = Obsplot.get_spec(*args, **kwargs)
+        spec = self.get_spec(*args, **kwargs)
+        if spec == "widget":
+            raise ValueError("Incorrect plot specification")
         display(ObsplotJsdom(spec).plot())
